# CRC4

> RC4 encryption for python in C

# Installation

```sh
pip install crc4
```

# Timing

```
Timing tests...
Python... 1.4015193369996268
C... 0.08188532599888276
```

C is over 17 times faster.
